@@ -30,21 +30,21 @@ class image_dehazer():
     def __BoundCon(self, HazeImg):
         if (len(HazeImg.shape) == 3):
 
-            t_b = np.maximum((self._A[0] - HazeImg[:, :, 0].astype(np.float)) / (self._A[0] - self.C0),
-                             (HazeImg[:, :, 0].astype(np.float) - self._A[0]) / (self.C1 - self._A[0]))
-            t_g = np.maximum((self._A[1] - HazeImg[:, :, 1].astype(np.float)) / (self._A[1] - self.C0),
-                             (HazeImg[:, :, 1].astype(np.float) - self._A[1]) / (self.C1 - self._A[1]))
-            t_r = np.maximum((self._A[2] - HazeImg[:, :, 2].astype(np.float)) / (self._A[2] - self.C0),
-                             (HazeImg[:, :, 2].astype(np.float) - self._A[2]) / (self.C1 - self._A[2]))
+            t_b = np.maximum((self._A[0] - HazeImg[:, :, 0].astype(float)) / (self._A[0] - self.C0),
+                             (HazeImg[:, :, 0].astype(float) - self._A[0]) / (self.C1 - self._A[0]))
+            t_g = np.maximum((self._A[1] - HazeImg[:, :, 1].astype(float)) / (self._A[1] - self.C0),
+                             (HazeImg[:, :, 1].astype(float) - self._A[1]) / (self.C1 - self._A[1]))
+            t_r = np.maximum((self._A[2] - HazeImg[:, :, 2].astype(float)) / (self._A[2] - self.C0),
+                             (HazeImg[:, :, 2].astype(float) - self._A[2]) / (self.C1 - self._A[2]))
 
             MaxVal = np.maximum(t_b, t_g, t_r)
             self._Transmission = np.minimum(MaxVal, 1)
         else:
-            self._Transmission = np.maximum((self._A[0] - HazeImg.astype(np.float)) / (self._A[0] - self.C0),
-                                            (HazeImg.astype(np.float) - self._A[0]) / (self.C1 - self._A[0]))
+            self._Transmission = np.maximum((self._A[0] - HazeImg.astype(float)) / (self._A[0] - self.C0),
+                                            (HazeImg.astype(float) - self._A[0]) / (self.C1 - self._A[0]))
             self._Transmission = np.minimum(self._Transmission, 1)
 
-        kernel = np.ones((self.boundaryConstraint_windowSze, self.boundaryConstraint_windowSze), np.float)
+        kernel = np.ones((self.boundaryConstraint_windowSze, self.boundaryConstraint_windowSze), float)
         self._Transmission = cv2.morphologyEx(self._Transmission, cv2.MORPH_CLOSE, kernel=kernel)
 
     def __LoadFilterBank(self):
